==> ejc-middlemeasurement-impl-3.0.0-20230404.070319-438-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractingvolumedetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 分包月度报量及申请报告月度子表
 * 
 * @author generator
 * 
 */
public class SubcontractingvolumedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String subitemCode; // 清单编号
    private java.lang.String subitemName; // 清单项目名称
    private java.lang.String unitpricedan; // 除税单价String类型
    private java.lang.String unit; // 单位
    private java.math.BigDecimal quantity; // 数量
    private java.math.BigDecimal unitprice; // 除税单价
    private java.math.BigDecimal taxUnitprice; // 含税单价
    private java.math.BigDecimal amounts; // 除税金额
    private java.math.BigDecimal taxAmounts; // 含税金额
    private java.math.BigDecimal cumulativeQuantity; // 数量
    private java.math.BigDecimal cumulativeAmounts; // 除税金额
    private java.math.BigDecimal cumulativeTaxAmounts; // 含税金额
    private java.math.BigDecimal examineQuantity; // 数量
    private java.math.BigDecimal examineUnitprice; // 除税单价
    private java.math.BigDecimal examineTaxUnitprice; // 含税单价
    private java.math.BigDecimal examineAmounts; // 除税金额
    private java.math.BigDecimal examineTaxAmounts; // 含税金额
    private java.math.BigDecimal examineCumulativeQuantity; // 数量
    private java.math.BigDecimal examineCumulativeAmounts; // 除税金额
    private java.math.BigDecimal examineCumulativeTaxAmounts; // 含税金额
    private java.math.BigDecimal contractNumber; // 合同量
    private java.lang.String source; // 来源
    private java.lang.String memo; // 备注
    private java.lang.String tid;
    private java.lang.String tpid;
    private String innercode; // 内码
    private String errorMsg; // 导入错误信息
    private java.lang.Long contractId; // 主表合同id
    private boolean leafFlag;//最末级
    private String section; // 区段
    private String subitemDesc; // 子目特征描述
    private BigDecimal sumNum; // 累计值(规则判断使用)
    private Integer contractSource; // 来源参照-1
    private java.math.BigDecimal taxRate; //税率

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public Integer getContractSource() {
        return contractSource;
    }

    public void setContractSource(Integer contractSource) {
        this.contractSource = contractSource;
    }

    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }

    private List<SubcontractingvolumedetailVO> children = new ArrayList<>();
    public List<SubcontractingvolumedetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<SubcontractingvolumedetailVO> children) {
        this.children = children;
    }

    public String getUnitpricedan() {
        return unitpricedan;
    }

    public void setUnitpricedan(String unitpricedan) {
        this.unitpricedan = unitpricedan;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }

    public String getSubitemCode() {
        return subitemCode;
    }

    public void setSubitemCode(String subitemCode) {
        this.subitemCode = subitemCode;
    }

    public String getSubitemName() {
        return subitemName;
    }

    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }

    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getQuantity() {
        return quantity;
    }

    /**
     * 数量
     */
    public void setQuantity(java.math.BigDecimal quantity) {
        this.quantity = quantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getUnitprice() {
        return unitprice;
    }

    /**
     * 除税单价
     */
    public void setUnitprice(java.math.BigDecimal unitprice) {
        this.unitprice = unitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getTaxUnitprice() {
        return taxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setTaxUnitprice(java.math.BigDecimal taxUnitprice) {
        this.taxUnitprice = taxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 除税金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    /**
     * 含税金额
     */
    public void setTaxAmounts(java.math.BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getCumulativeQuantity() {
        return cumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setCumulativeQuantity(java.math.BigDecimal cumulativeQuantity) {
        this.cumulativeQuantity = cumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getCumulativeAmounts() {
        return cumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setCumulativeAmounts(java.math.BigDecimal cumulativeAmounts) {
        this.cumulativeAmounts = cumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getCumulativeTaxAmounts() {
        return cumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setCumulativeTaxAmounts(java.math.BigDecimal cumulativeTaxAmounts) {
        this.cumulativeTaxAmounts = cumulativeTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineQuantity() {
        return examineQuantity;
    }

    /**
     * 数量
     */
    public void setExamineQuantity(java.math.BigDecimal examineQuantity) {
        this.examineQuantity = examineQuantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExamineUnitprice() {
        return examineUnitprice;
    }

    /**
     * 除税单价
     */
    public void setExamineUnitprice(java.math.BigDecimal examineUnitprice) {
        this.examineUnitprice = examineUnitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getExamineTaxUnitprice() {
        return examineTaxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setExamineTaxUnitprice(java.math.BigDecimal examineTaxUnitprice) {
        this.examineTaxUnitprice = examineTaxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineAmounts() {
        return examineAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineAmounts(java.math.BigDecimal examineAmounts) {
        this.examineAmounts = examineAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineTaxAmounts() {
        return examineTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineTaxAmounts(java.math.BigDecimal examineTaxAmounts) {
        this.examineTaxAmounts = examineTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineCumulativeQuantity() {
        return examineCumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setExamineCumulativeQuantity(java.math.BigDecimal examineCumulativeQuantity) {
        this.examineCumulativeQuantity = examineCumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineCumulativeAmounts() {
        return examineCumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineCumulativeAmounts(java.math.BigDecimal examineCumulativeAmounts) {
        this.examineCumulativeAmounts = examineCumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineCumulativeTaxAmounts() {
        return examineCumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineCumulativeTaxAmounts(java.math.BigDecimal examineCumulativeTaxAmounts) {
        this.examineCumulativeTaxAmounts = examineCumulativeTaxAmounts;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }
    public java.lang.String getMemo() {
        return memo;
    }
 
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public boolean isLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }

    public BigDecimal getContractNumber() {
        return contractNumber;
    }

    public void setContractNumber(BigDecimal contractNumber) {
        this.contractNumber = contractNumber;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20230830.034615-488-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractingvolumedetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;


/**
 * 分包月度报量及申请报告月度子表
 *
 * @author generator
 *
 */
public class SubcontractingvolumedetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String subitemCode; // 清单编号
    private java.lang.String subitemName; // 清单项目名称
    private java.lang.String unitpricedan; // 除税单价String类型
    private java.lang.String unit; // 单位
    private java.math.BigDecimal quantity; // 数量
    private java.math.BigDecimal unitprice; // 除税单价
    private java.math.BigDecimal taxUnitprice; // 含税单价
    private java.math.BigDecimal amounts; // 除税金额
    private java.math.BigDecimal taxAmounts; // 含税金额
    private java.math.BigDecimal cumulativeQuantity; // 数量
    private java.math.BigDecimal cumulativeAmounts; // 除税金额
    private java.math.BigDecimal cumulativeTaxAmounts; // 含税金额
    private java.math.BigDecimal examineQuantity; // 数量
    private java.math.BigDecimal examineUnitprice; // 除税单价
    private java.math.BigDecimal examineTaxUnitprice; // 含税单价
    private java.math.BigDecimal examineAmounts; // 除税金额
    private java.math.BigDecimal examineTaxAmounts; // 含税金额
    private java.math.BigDecimal examineCumulativeQuantity; // 数量
    private java.math.BigDecimal examineCumulativeAmounts; // 除税金额
    private java.math.BigDecimal examineCumulativeTaxAmounts; // 含税金额
    private java.math.BigDecimal contractNumber; // 合同量
    private java.lang.String source; // 来源
    private java.lang.String memo; // 备注
    private java.lang.String tid;
    private java.lang.String tpid;
    private String innercode; // 内码
    private String errorMsg; // 导入错误信息
    private java.lang.Long contractId; // 主表合同id
    private boolean leafFlag;//最末级
    private String section; // 区段
    private String subitemDesc; // 子目特征描述
    private BigDecimal sumNum; // 累计值(规则判断使用)
    private Integer contractSource; // 来源参照-1
    private java.math.BigDecimal taxRate; //税率

    private List<Long> ids;

    public List<Long> getIds() {
        return ids;
    }

    public void setIds(List<Long> ids) {
        this.ids = ids;
    }

    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }

    public Integer getContractSource() {
        return contractSource;
    }

    public void setContractSource(Integer contractSource) {
        this.contractSource = contractSource;
    }

    public BigDecimal getSumNum() {
        return sumNum;
    }

    public void setSumNum(BigDecimal sumNum) {
        this.sumNum = sumNum;
    }

    private List<SubcontractingvolumedetailVO> children = new ArrayList<>();
    public List<SubcontractingvolumedetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<SubcontractingvolumedetailVO> children) {
        this.children = children;
    }

    public String getUnitpricedan() {
        return unitpricedan;
    }

    public void setUnitpricedan(String unitpricedan) {
        this.unitpricedan = unitpricedan;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }

    public String getSubitemCode() {
        return subitemCode;
    }

    public void setSubitemCode(String subitemCode) {
        this.subitemCode = subitemCode;
    }

    public String getSubitemName() {
        return subitemName;
    }

    public void setSubitemName(String subitemName) {
        this.subitemName = subitemName;
    }

    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getQuantity() {
        return quantity;
    }

    /**
     * 数量
     */
    public void setQuantity(java.math.BigDecimal quantity) {
        this.quantity = quantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getUnitprice() {
        return unitprice;
    }

    /**
     * 除税单价
     */
    public void setUnitprice(java.math.BigDecimal unitprice) {
        this.unitprice = unitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getTaxUnitprice() {
        return taxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setTaxUnitprice(java.math.BigDecimal taxUnitprice) {
        this.taxUnitprice = taxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 除税金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    /**
     * 含税金额
     */
    public void setTaxAmounts(java.math.BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getCumulativeQuantity() {
        return cumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setCumulativeQuantity(java.math.BigDecimal cumulativeQuantity) {
        this.cumulativeQuantity = cumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getCumulativeAmounts() {
        return cumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setCumulativeAmounts(java.math.BigDecimal cumulativeAmounts) {
        this.cumulativeAmounts = cumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getCumulativeTaxAmounts() {
        return cumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setCumulativeTaxAmounts(java.math.BigDecimal cumulativeTaxAmounts) {
        this.cumulativeTaxAmounts = cumulativeTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineQuantity() {
        return examineQuantity;
    }

    /**
     * 数量
     */
    public void setExamineQuantity(java.math.BigDecimal examineQuantity) {
        this.examineQuantity = examineQuantity;
    }
    /**
     * 除税单价
     */
    public java.math.BigDecimal getExamineUnitprice() {
        return examineUnitprice;
    }

    /**
     * 除税单价
     */
    public void setExamineUnitprice(java.math.BigDecimal examineUnitprice) {
        this.examineUnitprice = examineUnitprice;
    }
    /**
     * 含税单价
     */
    public java.math.BigDecimal getExamineTaxUnitprice() {
        return examineTaxUnitprice;
    }

    /**
     * 含税单价
     */
    public void setExamineTaxUnitprice(java.math.BigDecimal examineTaxUnitprice) {
        this.examineTaxUnitprice = examineTaxUnitprice;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineAmounts() {
        return examineAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineAmounts(java.math.BigDecimal examineAmounts) {
        this.examineAmounts = examineAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineTaxAmounts() {
        return examineTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineTaxAmounts(java.math.BigDecimal examineTaxAmounts) {
        this.examineTaxAmounts = examineTaxAmounts;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getExamineCumulativeQuantity() {
        return examineCumulativeQuantity;
    }

    /**
     * 数量
     */
    public void setExamineCumulativeQuantity(java.math.BigDecimal examineCumulativeQuantity) {
        this.examineCumulativeQuantity = examineCumulativeQuantity;
    }
    /**
     * 除税金额
     */
    public java.math.BigDecimal getExamineCumulativeAmounts() {
        return examineCumulativeAmounts;
    }

    /**
     * 除税金额
     */
    public void setExamineCumulativeAmounts(java.math.BigDecimal examineCumulativeAmounts) {
        this.examineCumulativeAmounts = examineCumulativeAmounts;
    }
    /**
     * 含税金额
     */
    public java.math.BigDecimal getExamineCumulativeTaxAmounts() {
        return examineCumulativeTaxAmounts;
    }

    /**
     * 含税金额
     */
    public void setExamineCumulativeTaxAmounts(java.math.BigDecimal examineCumulativeTaxAmounts) {
        this.examineCumulativeTaxAmounts = examineCumulativeTaxAmounts;
    }
    /**
     * 来源
     */
    public java.lang.String getSource() {
        return source;
    }

    /**
     * 来源
     */
    public void setSource(java.lang.String source) {
        this.source = source;
    }
    public java.lang.String getMemo() {
        return memo;
    }

    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public boolean isLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(boolean leafFlag) {
        this.leafFlag = leafFlag;
    }

    public String getSection() {
        return section;
    }

    public void setSection(String section) {
        this.section = section;
    }

    public String getSubitemDesc() {
        return subitemDesc;
    }

    public void setSubitemDesc(String subitemDesc) {
        this.subitemDesc = subitemDesc;
    }

    public BigDecimal getContractNumber() {
        return contractNumber;
    }

    public void setContractNumber(BigDecimal contractNumber) {
        this.contractNumber = contractNumber;
    }
}
